@@ -24,6 +24,7 @@ from tsdoc0.python.question_abstract import QuestionAbstract
 from tsdoc0.python.question_review import QuestionReview
 from tsdoc0.python.question_shape import QuestionShape
 from tsdoc0.python.question_structure import QuestionStructure
+from tsdoc0.python.question_structure_no import QuestionStructureNo
 from tsdoc0.python.segment import Segment  # noqa :F401
 from tsdoc0.python.solution_item import SolutionItem
 from tsdoc0.python.solution_pseudocode import SolutionPseudocode
@@ -59,6 +60,7 @@ metamodel: TextXMetaModel = metamodel_from_file(
         QuestionReview,
         QuestionShape,
         QuestionStructure,
+        QuestionStructureNo,
         SolutionItem,
         SolutionPseudocode,
         SolutionShape,
