@@ -1,8 +1,16 @@
 from textwrap import fill
-from tsdoc0.python.model import Model
 from tsdoc0.python.segment import Segment
+from tsdoc0.python.utils import repr_parent
 from typing import Final
-from typing import Optional
+from typing import TYPE_CHECKING
+from typing import Union
+
+# Conditional import used because there would be a circular dependency
+# https://mypy.readthedocs.io/en/latest/common_issues.html#import-cycles
+if TYPE_CHECKING:
+    from tsdoc0.python.comment_abstract import CommentAbstract
+    from tsdoc0.python.comment_concrete import CommentConcrete
+
 
 import attr
 
@@ -19,7 +27,11 @@ def removesuffix(self: str, suffix: str, /) -> str:
 
 @attr.s(auto_attribs=True, kw_only=True)
 class CommentSentence(Segment):
-    parent: Optional[Model] = attr.ib(eq=False)
+    # Forward reference used because there would be a circular dependency
+    # https://mypy.readthedocs.io/en/latest/kinds_of_types.html#class-name-forward-references
+    parent: Union["CommentAbstract", "CommentConcrete", None] = attr.ib(
+        eq=False, repr=repr_parent
+    )
     indentation: Final[str]  # type: ignore[misc]
     text: Final[str]  # type: ignore[misc]
 
